<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
<!--
The Apache Software License, Version 1.1

Copyright (c) 1999, 2000 The Apache Software Foundation.  All rights
reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3. The end-user documentation included with the redistribution, if
   any, must include the following acknowlegement:
      "This product includes software developed by the
       Apache Software Foundation (http://www.apache.org/)."
   Alternately, this acknowlegement may appear in the software itself,
   if and wherever such third-party acknowlegements normally appear.

4. The names "The Jakarta Project", "Ant", and "Apache Software
   Foundation" must not be used to endorse or promote products derived
   from this software without prior written permission. For written
   permission, please contact apache@apache.org.

5. Products derived from this software may not be called "Apache"
   nor may "Apache" appear in their names without prior written
   permission of the Apache Group.

THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
====================================================================

This software consists of voluntary contributions made by many
individuals on behalf of the Apache Software Foundation.  For more
information on the Apache Software Foundation, please see
<http://www.apache.org/>.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" indent="yes"/>
	<xsl:param name="standAloneHTML" select="'true'"/>
	<xsl:param name="CSS" select="'stylesheet.css'"/>
	<!--
	Enables to define the first version of the release notes from which the documentation must be generated.
	-->
	<xsl:param name="firstVersion"/>
	<!--
	The last version the documentation must be generated for.
	-->
	<xsl:param name="lastVersion"/>
	<xsl:template match="/ReleaseNotes">
		<xsl:choose>
			<xsl:when test="$standAloneHTML = 'true'">
				<html>
					<head>
						<title>
							<xsl:text>Release Notes of </xsl:text>
							<xsl:value-of select="@ID"/>
						</title>
						<meta name="Author" content="Edouard Mercier"/>
						<link rel="StyleSheet" type="text/css">
							<xsl:attribute name="href"><xsl:value-of select="$CSS"/></xsl:attribute>
						</link>
					</head>
					<body>
						<p>
							<xsl:text>The following table shows the history of </xsl:text>
							<xsl:value-of select="@ID"/>
							<xsl:text> release notes.</xsl:text>
						</p>
						<xsl:call-template name="_print"/>
					</body>
				</html>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="_print"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="_print">
		<table border="1" width="100%">
			<tr>
				<th width="15%">Version</th>
				<th>Content</th>
				<th width="15%">Delivery</th>
			</tr>
			<xsl:apply-templates select="Releases"/>
		</table>
		<br/>
		<div class="copyright">Release notes generated by <strong>
				<i>
					<a href="http://xmlreleasenotes.free.fr" target="_blank">XMLReleaseNotes</a>
				</i>
			</strong>
		</div>
	</xsl:template>
	<xsl:template match="Releases">
		<xsl:variable name="actual_first_version">
			<xsl:choose>
				<xsl:when test="$firstVersion">
					<xsl:value-of select="$firstVersion"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="Release[last()]/@version"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="actual_last_version">
			<xsl:choose>
				<xsl:when test="$lastVersion">
					<xsl:value-of select="$lastVersion"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="Release[1]/@version"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="first_version_index">
			<xsl:for-each select="Release">
				<xsl:if test="@version = $actual_first_version">
					<xsl:value-of select="position()"/>
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="last_version_index">
			<xsl:for-each select="Release">
				<xsl:if test="@version = $actual_last_version">
					<xsl:value-of select="position()"/>
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<xsl:message>
			<xsl:value-of select="$actual_first_version"/>-<xsl:value-of select="$actual_last_version"/>-<xsl:value-of select="$first_version_index"/>-<xsl:value-of select="$last_version_index"/>
		</xsl:message>
		<xsl:for-each select="Release">
			<xsl:if test="position() &lt;= $first_version_index and position() &gt;= $last_version_index">
				<tr>
					<td>
						<b>
							<div class="version">
								<xsl:value-of select="@version"/>
							</div>
						</b>
						<xsl:if test="@buildDate">
							<br/>build date: <b>
								<xsl:value-of select="@buildDate"/>
							</b>
						</xsl:if>
						<xsl:if test="@deliveryDate">
							<br/>deliveryDate: <b>
								<xsl:value-of select="@deliveryDate"/>
							</b>
						</xsl:if>
					</td>
					<td>
						<div class="releaseSummary">
							<xsl:value-of select="Summary"/>
						</div>
						<br/>
						<xsl:apply-templates select="Tokens"/>
					</td>
					<td>
						<xsl:choose>
							<xsl:when test="Deliveries">
								<xsl:apply-templates select="Deliveries"/>
							</xsl:when>
							<xsl:otherwise>No delivery</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="Deliveries">
		<xsl:value-of select="Summary"/>
		<xsl:choose>
			<xsl:when test="Delivery">
				<ul>
					<xsl:for-each select="Delivery">
						<xsl:variable name="message">
							<xsl:choose>
								<xsl:when test="text()">
									<xsl:value-of select="."/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="@href"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<li>
							<div class="delivery">
								<a>
									<xsl:attribute name="href"><xsl:if test="/ReleaseNotes/Deliveries/@href"><xsl:value-of select="/ReleaseNotes/Deliveries/@href"/><xsl:text>/</xsl:text></xsl:if><xsl:value-of select="@href"/></xsl:attribute>
									<xsl:value-of select="$message"/>
								</a>
							</div>
						</li>
					</xsl:for-each>
				</ul>
			</xsl:when>
			<xsl:otherwise>No delivery</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="Release/Tokens">
		<xsl:if test="Token">
			<ol>
				<xsl:for-each select="Token">
					<li>type = '<xsl:value-of select="@type"/>'<br/>
						<xsl:call-template name="_printAskingPersons"/>
						<br/>
						<xsl:call-template name="_printContributors"/>
						<br/>
						<xsl:call-template name="_printFix"/>
						<br/>
						<xsl:value-of select="."/>
					</li>
				</xsl:for-each>
			</ol>
		</xsl:if>
	</xsl:template>
	<xsl:template name="_printAskingPersons">
		<xsl:if test="count(@askingPersonID | AskingPersons/AskingPerson/@ID) > 0">
			<xsl:text>asking person list:</xsl:text>
			<ul>
				<xsl:for-each select="@askingPersonID | AskingPersons/AskingPerson/@ID">
					<li>
						<xsl:value-of select="."/>
					</li>
				</xsl:for-each>
			</ul>
		</xsl:if>
	</xsl:template>
	<xsl:template name="_printContributors">
		<xsl:if test="count(@contributorID | Contributors/Contributor/@ID) > 0">
			<xsl:text>contributor list:</xsl:text>
			<ul>
				<xsl:for-each select="@contributorID | Contributors/Contributor/@ID">
					<li>
						<xsl:value-of select="."/>
					</li>
				</xsl:for-each>
			</ul>
		</xsl:if>
	</xsl:template>
	<xsl:template name="_printFix">
		<xsl:if test="@fixID">
			<xsl:text>fixes bug '</xsl:text>
			<xsl:value-of select="@fixID"/>
			<xsl:text>'</xsl:text>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
